@@ -104,7 +104,7 @@ PyObject *extension_blend_images(PyObject *self, PyObject *args, PyObject *kwarg
     int run_inline;
     char demultiply, source_over, destination_over;
     char *bottom_path, *top_path, *target_path, *algorithm;
-    PyObject *is_inline, *params_py;
+    PyObject *is_inline, *params_py, *options;
     struct pcv_image bottom, top;
     param values[32];
     params params = { 0, values };
@@ -115,6 +115,7 @@ PyObject *extension_blend_images(PyObject *self, PyObject *args, PyObject *kwarg
         "algorithm",
         "is_inline",
         "params",
+        "options",
         NULL
     };
 
@@ -124,19 +125,22 @@ PyObject *extension_blend_images(PyObject *self, PyObject *args, PyObject *kwarg
     algorithm = NULL;
     is_inline = NULL;
     params_py = NULL;
+    options = NULL;
 
     set_last_error(NULL);
 
     if(PyArg_ParseTupleAndKeywords(
         args,
         kwargs,
-        "sss|sO",
+        "sss|sOOO",
         kwlist,
         &bottom_path,
         &top_path,
         &target_path,
         &algorithm,
-        &is_inline
+        &is_inline,
+        &params_py,
+        &options
     ) == 0) { return NULL; }
 
     algorithm = algorithm == NULL ? "multiplicative" : algorithm;
@@ -189,7 +193,7 @@ PyObject *extension_blend_multiple(PyObject *self, PyObject *args, PyObject *kwa
     char *bottom_path, *top_path, *target_path, *algorithm = NULL;
     struct pcv_image bottom, top;
     PyObject *paths, *iterator, *iteratorAlgorithms, *element, *first, *second,
-        *is_inline, *algorithms, *algorithm_o, *algorithm_so, *params_py;
+        *is_inline, *algorithms, *algorithm_o, *algorithm_so, *params_py, *options;
     Py_ssize_t size, algorithms_size;
     param values[32];
     params params = { 0, values };
@@ -200,6 +204,7 @@ PyObject *extension_blend_multiple(PyObject *self, PyObject *args, PyObject *kwa
         "algorithms",
         "is_inline",
         "params",
+        "options",
         NULL
     };
 
@@ -213,20 +218,22 @@ PyObject *extension_blend_multiple(PyObject *self, PyObject *args, PyObject *kwa
     algorithms = NULL;
     is_inline = NULL;
     params_py = NULL;
+    options = NULL;
 
     set_last_error(NULL);
 
     if(PyArg_ParseTupleAndKeywords(
         args,
         kwargs,
-        "Os|sOOO",
+        "Os|sOOOO",
         kwlist,
         &paths,
         &target_path,
         &algorithm,
         &algorithms,
         &is_inline,
-        &params_py
+        &params_py,
+        &options
     ) == 0) { return NULL; }
 
     /* tries to determine the target values for the optional parameters
