@@ -376,6 +376,17 @@ ERROR_T blend_images_extra(
     char use_opencl
 ) {
     ERROR_T err;
+
+    if(bottom->width != top->width || bottom->height != top->height) {
+        RAISE_F(
+            "[blend_images_extra] Inconsistent image sizes %dx%d and %dx%d",
+            top->width,
+            top->height,
+            bottom->width,
+            bottom->height
+        );
+    }
+
     if(use_opencl == TRUE) {
         err = blend_images_opencl(bottom, top, algorithm, params);
     } else {
@@ -393,7 +404,19 @@ ERROR_T blend_images(
     int x, y;
     png_byte rb, gb, bb, ab;
     png_byte rt, gt, bt, at;
-    blend_algorithm *operation = get_blend_algorithm(algorithm);
+    blend_algorithm *operation;
+
+    if(bottom->width != top->width || bottom->height != top->height) {
+        RAISE_F(
+            "[blend_images] Inconsistent image sizes %dx%d and %dx%d",
+            top->width,
+            top->height,
+            bottom->width,
+            bottom->height
+        );
+    }
+
+    operation = get_blend_algorithm(algorithm);
 
     for(y = 0; y < bottom->height; y++) {
         png_byte *rowBottom = bottom->rows[y];
@@ -433,6 +456,16 @@ ERROR_T blend_images_i(
     png_byte rb, gb, bb, ab;
     png_byte rt, gt, bt, at;
 
+    if(bottom->width != top->width || bottom->height != top->height) {
+        RAISE_F(
+            "[blend_images_i] Inconsistent image sizes %dx%d and %dx%d",
+            top->width,
+            top->height,
+            bottom->width,
+            bottom->height
+        );
+    }
+
     for(y = 0; y < bottom->height; y++) {
         png_byte *rowBottom = bottom->rows[y];
         png_byte *rowTop = top->rows[y];
@@ -473,6 +506,16 @@ ERROR_T blend_images_source_over_fast(
     png_byte rb, gb, bb, ab;
     png_byte rt, gt, bt, at;
 
+    if(bottom->width != top->width || bottom->height != top->height) {
+        RAISE_F(
+            "[blend_images_source_over_fast] Inconsistent image sizes %dx%d and %dx%d",
+            top->width,
+            top->height,
+            bottom->width,
+            bottom->height
+        );
+    }
+
     for(y = 0; y < bottom->height; y++) {
         png_byte *rowBottom = bottom->rows[y];
         png_byte *rowTop = top->rows[y];
@@ -524,6 +567,16 @@ ERROR_T blend_images_destination_over_fast(
     png_byte rb, gb, bb, ab;
     png_byte rt, gt, bt, at;
 
+    if(bottom->width != top->width || bottom->height != top->height) {
+        RAISE_F(
+            "[blend_images_destination_over_fast] Inconsistent image sizes %dx%d and %dx%d",
+            top->width,
+            top->height,
+            bottom->width,
+            bottom->height
+        );
+    }
+
     for(y = 0; y < bottom->height; y++) {
         png_byte *rowBottom = bottom->rows[y];
         png_byte *rowTop = top->rows[y];
@@ -573,8 +626,21 @@ ERROR_T blend_images_debug(
     int x, y;
     png_byte rb, gb, bb, ab;
     png_byte rt, gt, bt, at;
-    blend_algorithm *operation = get_blend_algorithm(algorithm);
-    FILE *file = fopen(file_path, "wb");
+    blend_algorithm *operation;
+    FILE *file;
+
+    if(bottom->width != top->width || bottom->height != top->height) {
+        RAISE_F(
+            "[blend_images_debug] Inconsistent image sizes %dx%d and %dx%d",
+            top->width,
+            top->height,
+            bottom->width,
+            bottom->height
+        );
+    }
+
+    operation = get_blend_algorithm(algorithm);
+    file = fopen(file_path, "wb");
 
     for(y = 0; y < bottom->height; y++) {
         png_byte *rowBottom = bottom->rows[y];
